==> okteta-0.25.4.tar.xz: okteta-0.25.4/libs/kasten/controllers/viewsystem/close/closecontroller.cpp <==
/*
    This file is part of the Kasten Framework, made within the KDE community.

    Copyright 2006-2008 Friedrich W. H. Kossebau <kossebau@kde.org>

    This library is free software; you can redistribute it and/or
    modify it under the terms of the GNU Lesser General Public
    License as published by the Free Software Foundation; either
    version 2.1 of the License, or (at your option) version 3, or any
    later version accepted by the membership of KDE e.V. (or its
    successor approved by the membership of KDE e.V.), which shall
    act as a proxy defined in Section 6 of version 3 of the license.

    This library is distributed in the hope that it will be useful,
    but WITHOUT ANY WARRANTY; without even the implied warranty of
    MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the GNU
    Lesser General Public License for more details.

    You should have received a copy of the GNU Lesser General Public
    License along with this library. If not, see <http://www.gnu.org/licenses/>.
*/

#include "closecontroller.h"

// Kasten gui
#include <kasten/viewmanager.h>
// KF5
#include <KActionCollection>
#include <KStandardAction>
#include <KXMLGUIClient>
// Qt
#include <QAction>

namespace Kasten {

CloseController::CloseController(ViewManager* viewManager, KXMLGUIClient* guiClient)
    : mViewManager(viewManager)
{
    mCloseAction = KStandardAction::close(this, &CloseController::close, this);

    guiClient->actionCollection()->addAction(mCloseAction->objectName(), mCloseAction);

    setTargetModel(0);
}

void CloseController::setTargetModel(AbstractModel* model)
{
    mView = model ? model->findBaseModel<AbstractView*>() : 0;

    const bool hasView = (mView != 0);

    mCloseAction->setEnabled(hasView);
}

void CloseController::close()
{
    mViewManager->closeView(mView);
}

}

==> okteta_0.26.3.orig.tar.xz: okteta-0.26.3/libs/kasten/controllers/viewsystem/close/closecontroller.cpp <==
/*
    This file is part of the Kasten Framework, made within the KDE community.

    Copyright 2006-2008 Friedrich W. H. Kossebau <kossebau@kde.org>

    This library is free software; you can redistribute it and/or
    modify it under the terms of the GNU Lesser General Public
    License as published by the Free Software Foundation; either
    version 2.1 of the License, or (at your option) version 3, or any
    later version accepted by the membership of KDE e.V. (or its
    successor approved by the membership of KDE e.V.), which shall
    act as a proxy defined in Section 6 of version 3 of the license.

    This library is distributed in the hope that it will be useful,
    but WITHOUT ANY WARRANTY; without even the implied warranty of
    MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the GNU
    Lesser General Public License for more details.

    You should have received a copy of the GNU Lesser General Public
    License along with this library. If not, see <http://www.gnu.org/licenses/>.
*/

#include "closecontroller.hpp"

// Kasten gui
#include <Kasten/ViewManager>
// KF
#include <KActionCollection>
#include <KStandardAction>
#include <KXMLGUIClient>
// Qt
#include <QAction>

namespace Kasten {

CloseController::CloseController(ViewManager* viewManager, KXMLGUIClient* guiClient)
    : mViewManager(viewManager)
{
    mCloseAction = KStandardAction::close(this, &CloseController::close, this);

    guiClient->actionCollection()->addAction(mCloseAction->objectName(), mCloseAction);

    setTargetModel(0);
}

void CloseController::setTargetModel(AbstractModel* model)
{
    mView = model ? model->findBaseModel<AbstractView*>() : 0;

    const bool hasView = (mView != 0);

    mCloseAction->setEnabled(hasView);
}

void CloseController::close()
{
    mViewManager->closeView(mView);
}

}
